@@ -84,7 +84,7 @@ class Node:
         attrs = ', '.join(f'{k}={v}' for k, v in self.attrs.items() if k!='tag')
         return f'{indent}{self.tag} {attrs}'
 
-    def dump(self, *, nodes=True, datas=False, scripts=False):
+    def dump(self, *, nodes=True, datas=True, scripts=False):
         for node in self.walk_relative():
             if nodes:
                 print(node)
@@ -99,7 +99,7 @@ class Node:
         if self.data:
             data['data'] = self.data
         if self.nodes:
-            data['nodes'] = [sub.to_dict() for sub in self]
+            data['nodes'] = [sub.items for sub in self]
         return data
 
     @property
